summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKeith Short <keithshort@chromium.org>2021-08-06 14:20:50 -0600
committerCommit Bot <commit-bot@chromium.org>2021-11-19 23:28:37 +0000
commitb91e9c7c83f47c392c94f571d699e94dd568797f (patch)
treeb456d543aacfebf51d2ce1146f1fd5c5ef20e8ae
parent0e1462055e60aa0c08d7d5fe001d069825cc6f32 (diff)
downloadchrome-ec-b91e9c7c83f47c392c94f571d699e94dd568797f.tar.gz
config: rename CONFIG_HOSTCMD_LPC to CONFIG_HOST_INTERFACE_LPC
Rename CONFIG_HOSTCMD_LPC to CONFIG_HOST_INTERFACE_LPC. This makes the host interface selection configs distinct from configs used to enable/disable specific host commands. BUG=b:195416058 BRANCH=main TEST=compare_build.sh Signed-off-by: Keith Short <keithshort@chromium.org> Change-Id: I6d8722cd314aa7801ea11c1ead5ef6bdd113fd58 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3095841 Tested-by: Michał Barnaś <mb@semihalf.com> Reviewed-by: Jack Rosenthal <jrosenth@chromium.org>
-rw-r--r--baseboard/grunt/baseboard.h2
-rw-r--r--baseboard/ite_evb/baseboard.h2
-rw-r--r--board/bds/board.h2
-rw-r--r--board/coral/board.h2
-rw-r--r--board/it8xxx2_pdevb/board.h2
-rw-r--r--board/npcx_evb/board.h2
-rw-r--r--board/reef/board.h2
-rw-r--r--board/reef_it8320/board.h2
-rw-r--r--board/reef_mchp/board.h2
-rw-r--r--chip/it83xx/registers.h4
-rw-r--r--chip/it83xx/system.c2
-rw-r--r--chip/lm4/build.mk2
-rw-r--r--chip/lm4/config_chip.h2
-rw-r--r--chip/lm4/uart.c2
-rw-r--r--chip/mec1322/build.mk2
-rw-r--r--chip/mec1322/config_chip.h2
-rw-r--r--docs/configuration/config_ap_to_ec_comm.md2
-rw-r--r--include/config.h12
-rw-r--r--util/config_allowed.txt2
19 files changed, 25 insertions, 25 deletions
diff --git a/baseboard/grunt/baseboard.h b/baseboard/grunt/baseboard.h
index c97ece285f..5a79c48c63 100644
--- a/baseboard/grunt/baseboard.h
+++ b/baseboard/grunt/baseboard.h
@@ -36,7 +36,7 @@
#define CONFIG_BACKLIGHT_LID_ACTIVE_LOW
#define CONFIG_CMD_AP_RESET_LOG
#define CONFIG_HIBERNATE_PSL
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_HOSTCMD_SKUID
#define CONFIG_I2C
#define CONFIG_I2C_BUS_MAY_BE_UNPOWERED
diff --git a/baseboard/ite_evb/baseboard.h b/baseboard/ite_evb/baseboard.h
index 7fe309491c..23b3f80fba 100644
--- a/baseboard/ite_evb/baseboard.h
+++ b/baseboard/ite_evb/baseboard.h
@@ -30,7 +30,7 @@
#define CONFIG_SPI_CONTROLLER
#define CONFIG_SPI_FLASH_PORT 0
#define CONFIG_UART_HOST
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
/* Optional console commands */
#define CONFIG_CMD_FLASH
diff --git a/board/bds/board.h b/board/bds/board.h
index c859089f04..21dc2ad598 100644
--- a/board/bds/board.h
+++ b/board/bds/board.h
@@ -19,7 +19,7 @@
/* Modules we want to exclude */
#undef CONFIG_LID_SWITCH
-#undef CONFIG_HOSTCMD_LPC
+#undef CONFIG_HOST_INTERFACE_LPC
#undef CONFIG_PECI
#undef CONFIG_SWITCH
diff --git a/board/coral/board.h b/board/coral/board.h
index 0def402993..bac1a2c5f5 100644
--- a/board/coral/board.h
+++ b/board/coral/board.h
@@ -105,7 +105,7 @@
#define CONFIG_USBC_VCONN_SWAP
/* SoC / PCH */
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_CHIPSET_APOLLOLAKE
#define CONFIG_CHIPSET_RESET_HOOK
#define CONFIG_POWER_BUTTON
diff --git a/board/it8xxx2_pdevb/board.h b/board/it8xxx2_pdevb/board.h
index 8646c6c7b3..d23898f3aa 100644
--- a/board/it8xxx2_pdevb/board.h
+++ b/board/it8xxx2_pdevb/board.h
@@ -31,7 +31,7 @@
#undef CONFIG_SPI_CONTROLLER
#undef CONFIG_SPI_FLASH_PORT
#undef CONFIG_UART_HOST
-#undef CONFIG_HOSTCMD_LPC
+#undef CONFIG_HOST_INTERFACE_LPC
#undef CONFIG_CMD_MMAPINFO
#undef CONFIG_SWITCH
diff --git a/board/npcx_evb/board.h b/board/npcx_evb/board.h
index fc12b6d80a..5a22435396 100644
--- a/board/npcx_evb/board.h
+++ b/board/npcx_evb/board.h
@@ -12,7 +12,7 @@
#define CONFIG_ADC
#define CONFIG_PWM
#define CONFIG_SPI
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_PECI
/* Optional features */
diff --git a/board/reef/board.h b/board/reef/board.h
index 6b05bbc1ed..00544f7bf9 100644
--- a/board/reef/board.h
+++ b/board/reef/board.h
@@ -102,7 +102,7 @@
#define CONFIG_USBC_VCONN_SWAP
/* SoC / PCH */
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_CHIPSET_APOLLOLAKE
#define CONFIG_CHIPSET_RESET_HOOK
#define CONFIG_POWER_BUTTON
diff --git a/board/reef_it8320/board.h b/board/reef_it8320/board.h
index 3598aee233..cf29faa8f8 100644
--- a/board/reef_it8320/board.h
+++ b/board/reef_it8320/board.h
@@ -99,7 +99,7 @@
#define CONFIG_USBC_VCONN_SWAP
/* SoC / PCH */
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_CHIPSET_APOLLOLAKE
#define CONFIG_CHIPSET_RESET_HOOK
#define CONFIG_POWER_BUTTON
diff --git a/board/reef_mchp/board.h b/board/reef_mchp/board.h
index 5e31c5de98..5ae0cdf214 100644
--- a/board/reef_mchp/board.h
+++ b/board/reef_mchp/board.h
@@ -104,7 +104,7 @@
#define CONFIG_USBC_VCONN_SWAP
/* SoC / PCH */
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_CHIPSET_APOLLOLAKE
#define CONFIG_CHIPSET_RESET_HOOK
#define CONFIG_POWER_BUTTON
diff --git a/chip/it83xx/registers.h b/chip/it83xx/registers.h
index 34a2ddd6ae..2fde34f8f0 100644
--- a/chip/it83xx/registers.h
+++ b/chip/it83xx/registers.h
@@ -1456,7 +1456,7 @@ enum bram_indices {
BRAM_IDX_EC_LOG_STATUS = 0xc,
/* offset 0x0d ~ 0x1f are reserved for future use. */
-#if defined(CONFIG_HOSTCMD_LPC) || defined(CONFIG_HOSTCMD_ESPI)
+#if defined(CONFIG_HOST_INTERFACE_LPC) || defined(CONFIG_HOSTCMD_ESPI)
/*
* offset 0x20 ~ 0x7b are reserved for future use.
* (apply to x86 platform)
@@ -1508,7 +1508,7 @@ enum bram_ec_logs_status {
* And they will be used to save panic data if the GPG1 reset mechanism
* is enabled.
*/
-#if defined(CONFIG_HOSTCMD_LPC) || defined(CONFIG_HOSTCMD_ESPI)
+#if defined(CONFIG_HOST_INTERFACE_LPC) || defined(CONFIG_HOSTCMD_ESPI)
/* offset 0x80 ~ 0xbf */
#define IT83XX_BRAM_BANK1(i) REG8(IT83XX_BRAM_BASE + 0x80 + i)
#else
diff --git a/chip/it83xx/system.c b/chip/it83xx/system.c
index 16871e5826..9725ba4525 100644
--- a/chip/it83xx/system.c
+++ b/chip/it83xx/system.c
@@ -50,7 +50,7 @@ static void clear_reset_flags(void)
}
DECLARE_HOOK(HOOK_INIT, clear_reset_flags, HOOK_PRIO_LAST);
-#if !defined(CONFIG_HOSTCMD_LPC) && !defined(CONFIG_HOSTCMD_ESPI)
+#if !defined(CONFIG_HOST_INTERFACE_LPC) && !defined(CONFIG_HOSTCMD_ESPI)
static void system_save_panic_data_to_bram(void)
{
uint8_t *ptr = (uint8_t *)PANIC_DATA_PTR;
diff --git a/chip/lm4/build.mk b/chip/lm4/build.mk
index 26419d3a04..c1d7787bf3 100644
--- a/chip/lm4/build.mk
+++ b/chip/lm4/build.mk
@@ -20,7 +20,7 @@ chip-$(CONFIG_EEPROM)+=eeprom.o
chip-$(CONFIG_FANS)+=fan.o
chip-$(CONFIG_FLASH_PHYSICAL)+=flash.o
chip-$(CONFIG_I2C)+=i2c.o
-chip-$(CONFIG_HOSTCMD_LPC)+=lpc.o
+chip-$(CONFIG_HOST_INTERFACE_LPC)+=lpc.o
chip-$(CONFIG_PECI)+=peci.o
# pwm functions are implemented with the fan functions
chip-$(CONFIG_PWM)+=pwm.o fan.o
diff --git a/chip/lm4/config_chip.h b/chip/lm4/config_chip.h
index 4e442004c9..8e1ea51785 100644
--- a/chip/lm4/config_chip.h
+++ b/chip/lm4/config_chip.h
@@ -93,7 +93,7 @@
/* Optional features present on this chip */
#define CONFIG_ADC
#define CONFIG_HOSTCMD_ALIGNED
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_PECI
#define CONFIG_RTC
#define CONFIG_SWITCH
diff --git a/chip/lm4/uart.c b/chip/lm4/uart.c
index 0b923f0692..83136d0b46 100644
--- a/chip/lm4/uart.c
+++ b/chip/lm4/uart.c
@@ -123,7 +123,7 @@ static void uart_host_interrupt(void)
/* Clear transmit and receive interrupt status */
LM4_UART_ICR(CONFIG_UART_HOST) = 0x70;
-#ifdef CONFIG_HOSTCMD_LPC
+#ifdef CONFIG_HOST_INTERFACE_LPC
/*
* If we have space in our FIFO and a character is pending in LPC,
* handle that character.
diff --git a/chip/mec1322/build.mk b/chip/mec1322/build.mk
index 2b0c9cc229..dd0ef8cd90 100644
--- a/chip/mec1322/build.mk
+++ b/chip/mec1322/build.mk
@@ -22,7 +22,7 @@ chip-$(CONFIG_ADC)+=adc.o
chip-$(CONFIG_FANS)+=fan.o
chip-$(CONFIG_FLASH_PHYSICAL)+=flash.o
chip-$(CONFIG_I2C)+=i2c.o
-chip-$(CONFIG_HOSTCMD_LPC)+=lpc.o
+chip-$(CONFIG_HOST_INTERFACE_LPC)+=lpc.o
chip-$(CONFIG_PWM)+=pwm.o
chip-$(CONFIG_WATCHDOG)+=watchdog.o
ifndef CONFIG_KEYBOARD_NOT_RAW
diff --git a/chip/mec1322/config_chip.h b/chip/mec1322/config_chip.h
index 414fb492bf..951de3fb4f 100644
--- a/chip/mec1322/config_chip.h
+++ b/chip/mec1322/config_chip.h
@@ -103,7 +103,7 @@
#define CONFIG_MPU
#endif
#define CONFIG_DMA
-#define CONFIG_HOSTCMD_LPC
+#define CONFIG_HOST_INTERFACE_LPC
#define CONFIG_SPI
#define CONFIG_SWITCH
diff --git a/docs/configuration/config_ap_to_ec_comm.md b/docs/configuration/config_ap_to_ec_comm.md
index dbce22e31e..eb8ffa47db 100644
--- a/docs/configuration/config_ap_to_ec_comm.md
+++ b/docs/configuration/config_ap_to_ec_comm.md
@@ -11,7 +11,7 @@ following options.
- `CONFIG_HOSTCMD_SHI` - [SPI Host Interface](../ec_terms.md#shi) (SHI)
- `CONFIG_HOST_INTERFACE_HECI` - HECI interface
-- `CONFIG_HOSTCMD_LPC` - [LPC](../ec_terms.md#lpc) bus
+- `CONFIG_HOST_INTERFACE_LPC` - [LPC](../ec_terms.md#lpc) bus
- `CONFIG_HOSTCMD_ESPI` - [eSPI](../ec_terms.md#espi) bus
In [config.h], search for options that start with the same name as your selected
diff --git a/util/config_allowed.txt b/util/config_allowed.txt
index 2f3b8f3dab..99a442f1fa 100644
--- a/util/config_allowed.txt
+++ b/util/config_allowed.txt
@@ -502,7 +502,6 @@ CONFIG_HOSTCMD_I2C_ADDR_FLAGS
CONFIG_HOSTCMD_I2C_SLAVE_ADDR
CONFIG_HOSTCMD_I2C_CONTROL
CONFIG_HOSTCMD_LOCATE_CHIP
-CONFIG_HOSTCMD_LPC
CONFIG_HOSTCMD_PD
CONFIG_HOSTCMD_PD_CHG_CTRL
CONFIG_HOSTCMD_PD_PANIC
@@ -520,6 +519,7 @@ CONFIG_HOST_EVENT64
CONFIG_HOST_EVENT64_REPORT_MASK
CONFIG_HOST_EVENT_REPORT_MASK
CONFIG_HOST_INTERFACE_HECI
+CONFIG_HOST_INTERFACE_LPC
CONFIG_HWTIMER_64BIT
CONFIG_HW_CRC
CONFIG_HW_SPECIFIC_UDELAY
diff --git a/include/config.h b/include/config.h
index dab353cbc0..724b06ac5e 100644
--- a/include/config.h
+++ b/include/config.h
@@ -3146,12 +3146,12 @@
/*
* EC supports x86 host communication with AP. This can either be through LPC
* or eSPI. The CONFIG_HOSTCMD_X86 will get automatically defined if either
* CONFIG_HOSTCMD_LPC or CONFIG_HOSTCMD_ESPI are defined. LPC and eSPI are
* mutually exclusive.
*/
#undef CONFIG_HOSTCMD_X86
/* Support host command interface over LPC bus. */
-#undef CONFIG_HOSTCMD_LPC
+#undef CONFIG_HOST_INTERFACE_LPC
/* Support host command interface over eSPI bus. */
#undef CONFIG_HOSTCMD_ESPI
@@ -5641,16 +5641,16 @@
* Automatically define CONFIG_HOSTCMD_X86 if either child option is defined.
* Ensure LPC and eSPI are mutually exclusive
*/
-#if defined(CONFIG_HOSTCMD_LPC) || defined(CONFIG_HOSTCMD_ESPI)
+#if defined(CONFIG_HOST_INTERFACE_LPC) || defined(CONFIG_HOSTCMD_ESPI)
#define CONFIG_HOSTCMD_X86
#endif
-#if defined(CONFIG_HOSTCMD_LPC) && defined(CONFIG_HOSTCMD_ESPI)
+#if defined(CONFIG_HOST_INTERFACE_LPC) && defined(CONFIG_HOSTCMD_ESPI)
#error Must select only one type of host communication bus.
#endif
#if defined(CONFIG_HOSTCMD_X86) && \
- !defined(CONFIG_HOSTCMD_LPC) && \
+ !defined(CONFIG_HOST_INTERFACE_LPC) && \
!defined(CONFIG_HOSTCMD_ESPI)
#error Must select one type of host communication bus.
#endif
@@ -3146,12 +3146,12 @@
* EC supports x86 host communication with AP. This can either be through LPC
* or eSPI. The CONFIG_HOSTCMD_X86 will get automatically defined if either
- * CONFIG_HOSTCMD_LPC or CONFIG_HOSTCMD_ESPI are defined. LPC and eSPI are
- * mutually exclusive.
+ * CONFIG_HOST_INTERFACE_LPC or CONFIG_HOSTCMD_ESPI are defined.
+ * LPC and eSPI are mutually exclusive.
*/
#undef CONFIG_HOSTCMD_X86